From b8f310096632d2c7b82212b7e5dbf90e98249ec1 Mon Sep 17 00:00:00 2001
From: Francois-Rene Rideau <tunes@google.com>
Date: Tue, 18 Dec 2012 11:42:19 -0500
Subject: [PATCH] 2.26.32: Fix type for static-file (broken in previous
 2.26.31).

---
 asdf.asd  | 2 +-
 asdf.lisp | 7 ++++---
 2 files changed, 5 insertions(+), 4 deletions(-)

diff --git a/asdf.asd b/asdf.asd
index ef739648f..0f2c4e94e 100644
--- a/asdf.asd
+++ b/asdf.asd
@@ -14,7 +14,7 @@
   :licence "MIT"
   :description "Another System Definition Facility"
   :long-description "ASDF builds Common Lisp software organized into defined systems."
-  :version "2.26.31" ;; to be automatically updated by bin/bump-revision
+  :version "2.26.32" ;; to be automatically updated by bin/bump-revision
   :depends-on ()
   :components
   ((:file "asdf")))
diff --git a/asdf.lisp b/asdf.lisp
index efc810821..b2daa93b4 100644
--- a/asdf.lisp
+++ b/asdf.lisp
@@ -1,5 +1,5 @@
 ;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp ; coding: utf-8 -*-
 ;;; This is ASDF 2.26.31: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome:
 ;;; please mail to <asdf-devel@common-lisp.net>.
@@ -118,7 +118,7 @@
          ;; "2.345.6" would be a development version in the official upstream
          ;; "2.345.0.7" would be your seventh local modification of official release 2.345
          ;; "2.345.6.7" would be your seventh local modification of development version 2.345.6
-         (asdf-version "2.26.31")
+         (asdf-version "2.26.32")
          (existing-asdf (find-class 'component nil))
          (existing-version *asdf-version*)
          (already-there (equal asdf-version existing-version)))
@@ -2051,7 +2051,8 @@ PREVIOUS-TIME when not null is the time at which the PREVIOUS system was loaded.
   ((type :initform "c")))
 (defclass java-source-file (source-file)
   ((type :initform "java")))
-(defclass static-file (source-file) ())
+(defclass static-file (source-file)
+  ((type :initform nil)))
 (defclass doc-file (static-file) ())
 (defclass html-file (doc-file)
   ((type :initform "html")))
@@ -1,5 +1,5 @@
 ;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp ; coding: utf-8 -*-
-;;; This is ASDF 2.26.31: Another System Definition Facility.
+;;; This is ASDF 2.26.32: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome:
-- 
GitLab